capture log close sublog
log using "$prdir/log/cw/qcew_cty_to_cz.txt", name(sublog) text replace

*-------------------------------------------------------------------------------
* Description: Collapse the QCEW data (2014-2018) into commuting zones (CZs)
* Calculates employees, establishments, and wagebill by industry-by-CZ. 
* Keep only the contiguous 48 states. Collapse at CZ level using program 
* by David Dorn.
*
* Author: Justin Wiltshire 
*	
* Updated: Novemer 14, 2019
*-------------------------------------------------------------------------------

/* Load David Dorn's 1990 county to CZ crosswalk and drop Alaska & Hawaii
qui use "$prdir/cw/geo/dta/cty_cz/src/cw_cty_czone.dta", clear

* Drop Alaska and Hawaii
qui drop if inlist(floor(cty_fips/1000), 2, 15)

qui save "$prdir/cw/geo/dta/cty_cz/cln/cw_cty_czone.dta", replace
*/

* Load the QCEW data
qui use "$prdir/dta/cln/qcew/qcew_naics_cty.dta", clear

* Drop Alaska and Hawaii
qui drop if inlist(floor(cty_fips/1000), 2, 15)

* Merge in the updated county-to-CZ crosswalk
** cty_fips 30113 is uninhabited and 51780 is mapped into a county mapped into the same CZ
merge m:1 cty_fips using "$prdir/cw/geo/dta/cty_cz/cln/cw_cty_czone.dta", nogenerate noreport keep(3)

* Keep observations from jan2014 - sep2018
qui keep if inrange(tm, 648, 704)

* Generate flags for missings or zeros
foreach v in emp estabs wagebill {
	qui gen num_mi_or_0_cty_`v' = (mi(`v') | `v' == 0)
}

* Collapse into commuting zones
collapse (sum) emp estabs wagebill num_mi_or_0_cty_*, by(czone tm naics)

* Create year and quarter variables
qui gen year = yofd(dofm(tm))
qui gen quarter = quarter(dofm(tm))

* Log the variables of interest
foreach var in emp estabs wagebill {
  qui gen ln_`var' = ln(`var')
}

* Create a few derived variables
qui gen tot_emp = emp if naics == 10
bysort czone tm (naics): replace tot_emp = tot_emp[1]
qui gen prop_emp = emp/tot_emp
qui gen avg_wkly_wage = wagebill/(13*emp)
qui gen ln_avg_wkly_wage = ln(avg_wkly_wage)

/*
* Create a few derived variables
qui gen tot_emp = emp if naics == 10
bysort czone tm (naics): replace tot_emp = tot_emp[1]
levelsof(naics), local(ind)
foreach i of local ind {
  qui gen prop_emp_`i' = emp/tot_emp if naics == `i'
  qui gen avg_wkly_wage_`i' = wagebill/(13*emp) if naics == `i'
  qui gen ln_avg_wkly_wage_`i' = ln(avg_wkly_wage_`i') if naics == `i'
}
*/

* Clean-up
drop tot_emp
rename czone cz
sort cz tm
order cz tm year quarter

* Label variables
lab var cz "Commuting zone code"
lab var emp "Number of employees"
lab var estabs "Number of establishments"
lab var wagebill "Wagebill"
lab var ln_emp "log employees"
lab var ln_estabs "log establishments"
lab var ln_wagebill "log wagebill"
lab var prop_emp "Industry proportion of total employment"
lab var avg_wkly_wage "Industry average weekly compensation"
lab var ln_avg_wkly_wage "log industry avg. weekly compensation"
lab var num_mi_or_0_cty_emp "# contributing counties w/ mi or 0 emp"
lab var num_mi_or_0_cty_estabs "# contributing counties w/ mi or 0 estabs"
lab var num_mi_or_0_cty_wagebill "# contributing counties w/ mi or 0 wagebill"

* Save the data
save "$prdir/dta/cln/qcew/qcew_naics_cz.dta", replace

* Close the log file
log close sublog


