capture log close sublog
log using "$prdir/log/cw/qwi_cty_to_cz.txt", name(sublog) text replace

*-------------------------------------------------------------------------------
* Description: Collapse the QWI data files (2014Q1-2018Q3) into commuting zones 
* (CZs). Calculates employees and wagebill by industry-by-CZ. 
* Keep only the contiguous 48 states. Collapse at CZ level using program 
* by David Dorn.
*
* Author: Justin Wiltshire 
*	
* Updated: July 31, 2020
*-------------------------------------------------------------------------------

* Loop over the QWI data sets
foreach z in nonhisp hisp nonhisp_white lessthanhs hsorless somecollplus all_ethnic {

	* Load the data
	qui use "$prdir/dta/cln/qwi/qwi_naics_cty_`z'.dta", clear
	
	* Merge in the crosswalk
	qui merge m:1 cty_fips using "$prdir/cw/geo/dta/cty_cz/cln/cw_cty_czone.dta", nogenerate noreport keep(3)

	* Keep observations from jan2014 - sep2018
	qui keep if inrange(tm, 648, 704)

	* Generate flags for missings or zeros
	foreach v in emp wagebill {
		qui gen num_mi_or_0_cty_`v' = (mi(`v') | `v' == 0)
	}

	* Collapse into commuting zones
	collapse (sum) emp wagebill num_mi_or_0_cty_*, by(czone tm naics)

	* Create year and quarter variables
	qui gen year = yofd(dofm(tm))
	qui gen quarter = quarter(dofm(tm))

	* Log the variables of interest
	foreach var in emp wagebill {
		qui gen ln_`var' = ln(`var')
	}

	* Create a few derived variables
	qui gen tot_emp = emp if naics == 10
	bysort czone tm (naics): replace tot_emp = tot_emp[1]
	qui gen prop_emp = emp/tot_emp
	qui gen avg_wkly_wage = wagebill/(13*emp)
	qui gen ln_avg_wkly_wage = ln(avg_wkly_wage)


	* Clean-up
	drop tot_emp
	rename czone cz
	sort cz tm
	order cz tm year quarter

	* Label variables
	lab var cz "Commuting zone code"
	lab var emp "Number of employees"
	lab var wagebill "Wagebill"
	lab var ln_emp "log employees"
	lab var ln_wagebill "log wagebill"
	lab var prop_emp "Industry proportion of total employment"
	lab var avg_wkly_wage "Industry average weekly compensation"
	lab var ln_avg_wkly_wage "log industry avg. weekly compensation"
	lab var num_mi_or_0_cty_emp "# contributing counties w/ mi or 0 emp"
	lab var num_mi_or_0_cty_wagebill "# contributing counties w/ mi or 0 wagebill"

	* Compress and save the data
	compress
	save "$prdir/dta/cln/qwi/qwi_naics_cz_`z'.dta", replace
}

* Close the log file
log close sublog


