capture log close sublog
log using "$prdir/log/analysis/qcew/merge_te_2013.txt", name(sublog) text replace

*-------------------------------------------------------------------------------
* Description: Merge the treatment effect results from the synthetic control and
* the placebo synthetic control estimations (2013 - 2018)
* Author: Justin Wiltshire
	
* Updated: November 14, 2019
*-------------------------------------------------------------------------------

* Load the cleaned and deseasonalized QCEW data so the selection of CZs is 
* identical to the synthetic control estimations
qui use "$prdir/dta/cln/qcew/deseasonalized_qcew_naics_cz_2013.dta", clear

* Change settings for the synthetic control
qui set matsize 11000

* Exclude all counties with >= 0.0001 FEMA applications per capita from donor pool
foreach z of numlist $cz_droplist {
	qui drop if cz == `z'
}

* Keep for 2013 and later
qui keep if year >= 2013

tempfile core
qui save "`core'"

* Run employment synthetic control for Orlando, selected NAICS supersectors
foreach ind of numlist 10 23 44 72 { 
	qui use "`core'", clear

	* Restrict the donor pool to CZs of appropriate size
    qui sum emp if naics == `ind', d
    qui keep if emp >= r(p75) & naics == `ind'
      
	* Keep only CZs which observe the industry in each period and skip the estimations if the CZ is dropped from the sample
	bysort cz: egen ct = count(ln_emp)
	qui sum ct, d
	qui gen rmax = r(max)
	qui sum ct if cz == 7400, d
	if r(N) == rmax {
		qui keep if ct == rmax              
		qui levelsof(cz), local(CZ)
		  
		* Run for each variable				
		foreach lhs in resid_ln_emp resid_ln_avg_wkly_wage resid_ln_wagebill resid_ln_estabs {
					
			* Load the Orlando results and set up the dataset for creating the graphs
			qui use "$prdir/dta/analysis/qcew/sc_results_dta/cz_7400/`lhs'/deseasonalize_n`ind'_2013.dta", clear
			qui gen time = yq(year(dofm(_time)), ceil(month(dofm(_time))/3))
			qui format time %tq
			qui gen tr_effect_orl = _Y_treated - _Y_synthetic
			qui keep _time time tr_effect_orl
			qui keep if !mi(_time)
			qui save "$prdir/dta/analysis/qcew/sc_merged/cz_7400/`lhs'/deseasonalize_n`ind'_merged_2013.dta", replace
				  
			* Run through the results from each of the donor pool CZs as a placebo test, and merge with the above
			foreach czone of local CZ {
				if "`czone'" != "7400" {
					qui use "$prdir/dta/analysis/qcew/sc_placebo_tests/cz_7400/`lhs'/n`ind'_cz`czone'_2013.dta", clear
					qui gen time = yq(year(dofm(_time)), ceil(month(dofm(_time))/3))
					qui format time %tq
					qui gen tr_effect_`czone' = _Y_treated - _Y_synthetic
					qui keep _time time tr_effect_`czone'
					qui keep if !mi(_time)
					merge 1:1 _time using "$prdir/dta/analysis/qcew/sc_merged/cz_7400/`lhs'/deseasonalize_n`ind'_merged_2013.dta", nogenerate noreport
					qui format _time %tm
					qui save "$prdir/dta/analysis/qcew/sc_merged/cz_7400/`lhs'/deseasonalize_n`ind'_merged_2013.dta", replace
				}
			}
		}
	}
}
	
* Close the log file
log close sublog
