capture log close sublog
log using "$prdir/log/analysis/qcew/distn_treatment_effect_nicegraphs.txt", name(sublog) text replace

*-------------------------------------------------------------------------------
* Description: Graph the (sample) empirical distributions of the estimated 
* average treatment effects for employment in each sector
* Author: Justin Wiltshire
	
* Updated: February 25, 2021
*-------------------------------------------------------------------------------

local avgs = 1000

* Change settings for the synthetic control
set matsize 11000

*---------------------// * Top 5 *//--------------------------------------------

* Begin loop
local graphlist_te_emp ""
foreach ind of numlist 10 23 44 72 {
	
	* Create labels and titles
	if `ind' == 10 {
		local ind_label "Panel A: Aggregate"
		local tlab "tlabel(`""')"
	}
	else if `ind' == 23 {
		local ind_label "Panel B: Construction"
		local tlab "tlabel(`""')"
	}
	else if `ind' == 44 {
		local ind_label "Panel C: Retail"
		local tlab "tlabel(2014m1(12)2018m1, angle(45))"
	}
	else if `ind' == 72 {
		local ind_label "Panel D: Hospitality"
		local tlab "tlabel(2014m1(12)2018m1, angle(45))"
	}
		
	* Ensure necessary folders exist
	qui capture mkdir "$prdir/out/analysis/att"
	qui capture mkdir "$prdir/out/analysis/att/nice_graphs"
						
	* Difference the data
	use "$prdir/dta/analysis/qcew/distribution/resid_ln_emp/`ind'/distn_n`avgs'.dta", clear
	sort placebo_id time
						
	* Create macros with the number of placebos for the plot legend
	qui levelsof(placebo_id), local(id)
		
	* Locals for graph indicators
	qui sum tr_effect if placebo_id == 0 & time == 704
	local x = 100*r(mean)
	local att = substr("`x'", 1, 3)
	if `x' < 1 {
		local att "0`att'"
	}
	qui sum pval if placebo_id == 0 & time == 704
	local x = r(mean)
	local pval = substr("`x'", 1, 5)
	local pval "0`pval'"
		
	* Clean up and reshape wide
	keep time tr_effect placebo_id
	qui reshape wide tr_effect, i(time) j(placebo_id)
	format time %tm
							
	* Create locals for the placebo results and put treatment effects in percent terms
	local placebos
	foreach i of local id {
		if "`i'" != "0" {
			local placebos "`placebos' line tr_effect`i' time if inrange(tr_effect`i', -10, 10), lcolor(gs8) lwidth(vthin) lp(solid) || "
			qui replace tr_effect`i' = 100*tr_effect`i'
		}
	}
			   
	* Put the actual ATT treatment effects in percent terms
	qui replace tr_effect0 = 100*tr_effect0
		
	* Create the graphs
	#delimit ;
		twoway  
			`placebos'||
			(line tr_effect0 time if inrange(tr_effect0, -10, 10), lcolor(black) lp(solid)),
			xline(691.5, lwidth(1.5) lcolor(gs12))
			xline(691 692, lp(dot) lcolor(gs8))
			title("`ind_label'") xtitle("") ytitle("")
			`tlab'
			plotregion(margin(zero))
			yscale(range(-10 10)) ylabel(-10 (4) 10)
			graphregion(fcolor(white))
			legend(order(1001 "ATT, five most treated CZs" 1000 "Placebo average ATTs") region(lwidth(thin) lcolor(gs10)));
		#delimit cr
		
	* Copy it
	graph copy gr_emp`ind', replace
	local graphlist_te_emp "`graphlist_te_emp' gr_emp`ind'"
}

* Combine the the employment TE plots into a single graph
qui grc1leg `graphlist_te_emp', imargin(vsmall) legendfrom(gr_emp72)
qui graph export "$prdir/out/analysis/att/nice_graphs/5top_te_combined_emp.pdf", replace

*---------------------// * Top 3 *//--------------------------------------------
	
* Begin loop
local graphlist_te_emp ""
foreach ind of numlist 10 23 44 72 {
	
	* Create labels and titles
	if `ind' == 10 {
		local ind_label "Panel A: Aggregate"
		local tlab "tlabel(`""')"
	}
	else if `ind' == 23 {
		local ind_label "Panel B: Construction"
		local tlab "tlabel(`""')"
	}
	else if `ind' == 44 {
		local ind_label "Panel C: Retail"
		local tlab "tlabel(2014m1(12)2018m1, angle(45))"
	}
	else if `ind' == 72 {
		local ind_label "Panel D: Hospitality"
		local tlab "tlabel(2014m1(12)2018m1, angle(45))"
	}
		
	* Ensure necessary folders exist
	qui capture mkdir "$prdir/out/analysis/att"
	qui capture mkdir "$prdir/out/analysis/att/nice_graphs"
						
	* Difference the data
	use "$prdir/dta/analysis/qcew/distribution/3top/resid_ln_emp/`ind'/distn_n`avgs'.dta", clear
	sort placebo_id time
						
	* Create macros with the number of placebos for the plot legend
	qui levelsof(placebo_id), local(id)
		
	* Locals for graph indicators
	qui sum tr_effect if placebo_id == 0 & time == 704
	local x = 100*r(mean)
	local att = substr("`x'", 1, 3)
	if `x' < 1 {
		local att "0`att'"
	}
	qui sum pval if placebo_id == 0 & time == 704
	local x = r(mean)
	local pval = substr("`x'", 1, 5)
	local pval "0`pval'"
	
	* Clean up and reshape wide
	keep time tr_effect placebo_id
	qui reshape wide tr_effect, i(time) j(placebo_id)
	format time %tm
						
	* Create locals for the placebo results and put treatment effects in percent terms
	local placebos
	foreach i of local id {
		if "`i'" != "0" {
			local placebos "`placebos' line tr_effect`i' time if inrange(tr_effect`i', -10, 10), lcolor(gs8) lwidth(vthin) lp(solid) || "
			qui replace tr_effect`i' = 100*tr_effect`i'
		}
	}
		   
	* Put the actual ATT treatment effects in percent terms
	qui replace tr_effect0 = 100*tr_effect0
	
	* Create the graphs
	#delimit ;
		twoway  
			`placebos'||
			(line tr_effect0 time if inrange(tr_effect0, -10, 10), lcolor(black) lp(solid)),
			xline(691.5, lwidth(1.5) lcolor(gs12))
			xline(691 692, lp(dot) lcolor(gs8))
			title("`ind_label'") xtitle("") ytitle("")
			`tlab'
			plotregion(margin(zero))
			yscale(range(-10 10)) ylabel(-10 (4) 10)
			graphregion(fcolor(white))
			legend(order(1001 "ATT, three most treated CZs" 1000 "Placebo average ATTs") region(lwidth(thin) lcolor(gs10)));
		#delimit cr
	
	* Copy it
	graph copy gr_emp`ind', replace
	local graphlist_te_emp "`graphlist_te_emp' gr_emp`ind'"
}

* Combine the the employment TE plots into a single graph
qui grc1leg `graphlist_te_emp', imargin(vsmall) legendfrom(gr_emp72)
qui graph export "$prdir/out/analysis/att/nice_graphs/3top_te_combined_emp.pdf", replace
	
* Close the log file
log close sublog
