capture log close sublog
log using "$prdir/log/analysis/qcew/irma_cz_p_values.txt", name(sublog) text replace

*-------------------------------------------------------------------------------
* Description: Run the synthetic control estimates and calculated the p-values
* for CZ 7600 (Jacksonville) as an Irma robustness check
* Author: Justin Wiltshire
	
* Updated: February 25, 2021
*-------------------------------------------------------------------------------

*-------------------------------------------------------------------------------
* Get the synthetic control placebo treatment effects for CZ 7600
*-------------------------------------------------------------------------------

local c = 7600
 
* Load the cleaned and deseasonalized QCEW data
qui use "$prdir/dta/cln/qcew/deseasonalized_qcew_naics_cz.dta", clear
  
* Change settings for the synthetic control
qui set matsize 11000
	  
* Exclude all counties with >= 0.0001 FEMA applications per capita from donor pool
foreach z of numlist $cz_droplist {
	if "`c'" != "`z'" & "`c'" != "7400" {
		drop if cz == `z'
	}
}

* Keep for 2014 and later (after the recovery had firmly taken root)
keep if year >= 2014 
tempfile core
save "`core'", replace
		
* Run for selected NAICS supersectors
foreach ind of numlist 10 23 {
	use "`core'", clear
	local pdflist_`ind'
			
	* Restrict the donor pool to CZs of appropriate size
	qui sum emp if naics == `ind', d
	keep if (emp >= r(p75) | cz == `c') & naics == `ind'
			
	* Keep the industry of interest  
	keep if naics == `ind'
		  
	* Keep only CZs which observe the industry in each period and skip the estimations if the CZ is dropped from the sample
	bysort cz: egen ct = count(ln_emp)
	qui sum ct, d
	qui gen rmax = r(max)
	qui sum ct if cz == `c', d
	if r(N) == rmax {
		keep if ct == rmax
				
		* Set up and run the synthetic control estimations
		tsset cz tm
		
		* Synthetic control for each of the LHS variables
		foreach lhs of varlist resid_ln_emp resid_ln_avg_wkly_wage resid_ln_estabs {
			if "`lhs'" == "resid_ln_emp" {
				local emp_qtr "`lhs'(691)"
				local trperiod = 692
				local last_pretreat = 691
			}
			else if "`lhs'" != "resid_ln_emp" {
				local emp_qtr ""
				
				* Non-employment variables are only observed quarterly
				keep if inlist(month(dofm(tm)), 2, 5, 8, 11)
				local trperiod = 691
				local last_pretreat = 688
			}
			
			* Note the particular run
			di "Placebo treated CZ `c'; NAICS `ind'; LHS `lhs'"
			
			#delimit ;
				qui synth 
					`lhs' `emp_qtr' `lhs'(688) `lhs'(685) `lhs'(682) `lhs'(679) `lhs'(676) `lhs'(673) `lhs'(661) `lhs'(655) `lhs'(649)
					prop_emp_23(649(3)`last_pretreat') prop_emp_72(649(3)`last_pretreat'), trunit(`c') trperiod(`trperiod') fig 
					keep("$prdir/dta/analysis/qcew/sc_placebo_tests/cz_7400/`lhs'/n`ind'_cz`c'.dta") replace;
				#delimit cr 
							  
			tempfile g`ind'
			nicepdf "`g`ind''.pdf"
			local pdflist_`ind' "`pdflist_`ind'' `g`ind''.pdf"
		}
	}
}

*-------------------------------------------------------------------------------
* Merge with the other placebo synthetic control estimates
*-------------------------------------------------------------------------------

* Load the cleaned and deseasonalized QCEW data so the selection of CZs is 
* identical to the synthetic control estimations
qui use "$prdir/dta/cln/qcew/deseasonalized_qcew_naics_cz.dta", clear

* Exclude all counties with >= 0.0001 FEMA applications per capita from donor pool
foreach z of numlist $cz_droplist {
	if "`c'" != "`z'" & "`c'" != "7400" {
		drop if cz == `z'
	}
}

* Keep for 2014 and later (after the recovery had firmly taken root)
qui keep if year >= 2014
qui save "`core'", replace

* Run employment synthetic control for Orlando, selected NAICS supersectors
foreach ind of numlist 10 23 { 
	qui use "`core'", clear

	* Restrict the donor pool to CZs of appropriate size
	qui sum emp if naics == `ind', d
	qui keep if (emp >= r(p75) | cz == `c') & naics == `ind'
	  
	* Keep only CZs which observe the industry in each period and skip the estimations if the CZ is dropped from the sample
	bysort cz: egen ct = count(ln_emp)
	qui sum ct, d
	qui gen rmax = r(max)
	qui sum ct if cz == `c', d
	if r(N) == rmax {
		qui keep if ct == rmax              
		qui levelsof(cz), local(CZ)
		  
		* Run for each variable				
		foreach lhs in resid_ln_emp resid_ln_avg_wkly_wage resid_ln_estabs {
					
			* Load the Irma CZ (7600) results and set up the dataset for creating the graphs
			qui use "$prdir/dta/analysis/qcew/sc_placebo_tests/cz_7400/`lhs'/n`ind'_cz`c'.dta", clear
			qui gen time = yq(year(dofm(_time)), ceil(month(dofm(_time))/3))
			qui format time %tq
			qui gen tr_effect_`c' = _Y_treated - _Y_synthetic
			qui keep _time time tr_effect_`c'
			qui keep if !mi(_time)
			qui save "$prdir/dta/analysis/qcew/sc_merged/cz_7400/`lhs'/irma_`c'_n`ind'_merged.dta", replace
				  
			* Run through the results from each of the donor pool CZs as a placebo test, and merge with the above
			foreach czone of local CZ {
				if "`czone'" != "`c'" {
					if "`czone'" != "7400" {
						qui use "$prdir/dta/analysis/qcew/sc_placebo_tests/cz_7400/`lhs'/n`ind'_cz`czone'.dta", clear
					}
					else if "`czone'" == "7400" {
						qui use "$prdir/dta/analysis/qcew/sc_results_dta/cz_7400/`lhs'/deseasonalize_n`ind'.dta", clear
					}
					qui gen time = yq(year(dofm(_time)), ceil(month(dofm(_time))/3))
					qui format time %tq
					qui gen tr_effect_`czone' = _Y_treated - _Y_synthetic
					qui keep _time time tr_effect_`czone'
					qui keep if !mi(_time)
					merge 1:1 _time using "$prdir/dta/analysis/qcew/sc_merged/cz_7400/`lhs'/irma_`c'_n`ind'_merged.dta", nogenerate noreport
					qui format _time %tm
					qui save "$prdir/dta/analysis/qcew/sc_merged/cz_7400/`lhs'/irma_`c'_n`ind'_merged.dta", replace
				}
			}
		}
	}
}

*-------------------------------------------------------------------------------
* Calculate the values of interest
*-------------------------------------------------------------------------------

* Loop over selected NAICS supersectors and variables of interest
foreach ind of numlist 10 23 {
			 
	* Set up the loop for the outcome variables
	foreach lhs in ln_emp ln_avg_wkly_wage ln_estabs {
			
		* Set up the loop to yield six- and twelve-month impacts
		forval m = 0(6)6 {
			local z = `m' + 6
				
			* Load the data
			use "$prdir/dta/analysis/qcew/sc_merged/cz_7400/resid_`lhs'/irma_`c'_n`ind'_merged.dta", clear
						
			* Calculate the MSPE ratio and rank CZs
			if "`lhs'" == "ln_emp" {

				* Reshape the data
				qui reshape long tr_effect_, i(_time) j(cz)
				sort cz _time
								
				* Generate the MSPE ratio
				qui gen mspe_pre = .
				qui gen mspe_post`z'month = .
				qui distinct _time
				local post_periods = `z'
				local last_p = 692 + `z'
				levelsof(cz), local(cz)
				foreach CZ of local cz {
					egen mspe_pre_`CZ' = total(tr_effect^2) if cz == `CZ' & _time < 692
					replace mspe_pre = mspe_pre_`CZ'/44 if cz == `CZ'
					egen mspe_post`z'month_`CZ' = total(tr_effect^2) if cz == `CZ' & inrange(_time, 692, `last_p')
					replace mspe_post`z'month = mspe_post`z'month_`CZ'/`post_periods' if cz == `CZ'
					drop mspe_pre_`CZ' mspe_post`z'month_`CZ'
				}
				bysort cz (mspe_pre): replace mspe_pre = mspe_pre[1]
				bysort cz (mspe_post`z'month): replace mspe_post`z'month = mspe_post`z'month[1]
				qui gen ratio`z'month = mspe_post`z'month/mspe_pre
				qui keep if _time == `last_p'
			}
			else if "`lhs'" != "ln_emp" {

				* Reshape the data
				qui reshape long tr_effect_, i(time) j(cz)
				sort cz time
											
				* Generate the MSPE ratio
				qui gen mspe_pre = .
				qui gen mspe_post`z'month = .
				qui distinct _time
				if `m' == 0 {
					local k = 2
				}
				else if `m' == 6 {
					local k = 4
				}
				local post_periods = `k'
				local last_p = 230 + `k'
				levelsof(cz), local(cz)
				foreach CZ of local cz {
					egen mspe_pre_`CZ' = total(tr_effect^2) if cz == `CZ' & time < 230
					replace mspe_pre = mspe_pre_`CZ'/14 if cz == `CZ'
					egen mspe_post`z'month_`CZ' = total(tr_effect^2) if cz == `CZ' & inrange(time, 230, `last_p')
					replace mspe_post`z'month = mspe_post`z'month_`CZ'/`post_periods' if cz == `CZ'
					drop mspe_pre_`CZ' mspe_post`z'month_`CZ'
				}
				bysort cz (mspe_pre): replace mspe_pre = mspe_pre[1]
				bysort cz (mspe_post`z'month): replace mspe_post`z'month = mspe_post`z'month[1]
				qui gen ratio`z'month = mspe_post`z'month/mspe_pre
				qui keep if time == `last_p'
			}
									
			* Keep only variables we want
			keep cz tr_effect ratio*
								
			* Get the number of placebo CZs
			local j = _N - 1
			qui gen donor_sample_size = `j'

			* Generate the Irma CZ ranking
			sort ratio`z'month
			qui gen rank_ratio`z'month = _n
									
			* Keep only the relevant observation
			keep if cz == `c'
	
			* Generate the p-values
			qui gen p_value_ratio`z'month = (1 + `j' + 1 - rank_ratio`z'month)/(`j' + 1)
										
			* Keep variables of interest and merge with the other pseudo p-value data
			keep cz tr_effect ratio* rank donor_sample_size p_value*
			compress
			save "$prdir/dta/analysis/qcew/sc_pvalue/cz_7400/resid_`lhs'/irma_`c'_p_values_n`ind'_month`z'.dta", replace
		}
	}
}

*-------------------------------------------------------------------------------
* Make the individual tables
*-------------------------------------------------------------------------------

* Loop over six- and twelve-month impacts
forval z = 6(6)12 {

	* Loop over the LHS variables
	foreach lhs in ln_emp ln_avg_wkly_wage ln_estabs {
				 
		* Loop over the NAICS supersectors
		foreach ind of numlist 10 23 {
					
			* Define the industry labels
			if "`ind'" == "10" {
				local industry "Total"
				local industry2 ""
			}
			else if "`ind'" == "23" {
				local industry "Construction"
				local industry2 ""
			}
									
			* Load the data
			qui use "$prdir/dta/analysis/qcew/sc_pvalue/cz_7400/resid_`lhs'/irma_`c'_p_values_n`ind'_month`z'.dta", clear
							
			* Put the key figures in a matrix
			if "`lhs'" == "ln_emp" {
				qui sum tr_effect, d
				mat effect`ind' = r(mean)
				qui sum ratio`z'month, d
				mat mspe_ratio`ind' = r(mean)
				qui sum p_value_ratio`z'month, d
				mat mspe_pval`ind' = r(mean)
				mat mspe_stars`ind' = (r(mean) <= .1) + (r(mean) <= .05) + (r(mean) <= .01)
				qui sum donor_sample_size, d
				mat N`ind' = r(mean) + 1
			}	
			else if "`lhs'" != "ln_emp" {
				qui sum tr_effect, d
				mat effect`ind' = effect`ind', r(mean)
				qui sum ratio`z'month, d
				mat mspe_ratio`ind' = mspe_ratio`ind', r(mean)
				qui sum p_value_ratio`z'month, d
				mat mspe_pval`ind' = mspe_pval`ind', r(mean)
				mat mspe_stars`ind' = mspe_stars`ind', (r(mean) <= .1) + (r(mean) <= .05) + (r(mean) <= .01)
				qui sum donor_sample_size, d
				mat N`ind' = N`ind', (r(mean) + 1)
			}
							
			* Now make the tables *if* we've looped through to the last lhs variable (ln_avg_wkly_wage)
			if "`lhs'" == "ln_estabs" {
				
				* Combine the matrices into one
				mat vals`ind' = effect`ind'
				mat mspevals`ind' = mspe_ratio`ind'\mspe_pval`ind'
						
				* Make the individual tables
				frmttable using "$prdir/out/analysis/cz_`c'/tables/`z'_month/naics_`ind'", replace tex statmat(vals`ind') sdec(4) ///
				annotate(mspe_stars`ind') asymbol(*,**,***) ///
				ctitles("`industry'","Log","Log compensation","Log"\"`industry2'","employment","per worker","establishments") ///
				rtitles("Treatment effect")
				
				frmttable using "$prdir/out/analysis/cz_`c'/tables/`z'_month/naics_`ind'", replace tex statmat(mspevals`ind') sdec(4) ///
				rtitles("RMSPE"\"RMSPE p-value") append
				
				frmttable using "$prdir/out/analysis/cz_`c'/tables/`z'_month/naics_`ind'", replace tex statmat(N`ind') sdec(0) ///
				rtitles("N") append
			}
		}
	}
}

*-------------------------------------------------------------------------------
* Make the (residualized) combined tables
*-------------------------------------------------------------------------------

* Loop over the NAICS supersectors
foreach ind of numlist 10 23 {
				
	* Loop over the LHS variables
	foreach lhs in ln_emp ln_avg_wkly_wage ln_estabs {
				
		* Loop over six- and twelve-month impacts
		forval z = 6(6)12 {
						
			* Define the industry labels
			if "`ind'" == "10" {
				local industry "Total"
				local industry2 ""
			}
			else if "`ind'" == "23" {
				local industry "Construction"
				local industry2 ""
			}
			else if "`ind'" == "44" {
				local industry "Retail"
				local industry2 ""
			}
			else if "`ind'" == "72" {
				local industry "Accommodation \&"
				local industry2 "Food Services"
			}
									
			* Load the data
			qui use "$prdir/dta/analysis/qcew/sc_pvalue/cz_7400/resid_`lhs'/irma_`c'_p_values_n`ind'_month`z'.dta", clear
							
			* Put the key figures in a matrix
			qui sum tr_effect, d
			mat effect`ind'_`z'month = r(mean)
			qui sum ratio`z'month, d
			mat mspe_ratio`ind'_`z'month = r(mean)
			qui sum p_value_ratio`z'month, d
			mat mspe_pval`ind'_`z'month = r(mean)
			mat mspe_stars`ind'_`z'month = (r(mean) <= .1) + (r(mean) <= .05) + (r(mean) <= .01)
			qui sum donor_sample_size, d
			mat N`ind'_`z'month = r(mean) + 1
		}
					
		* Combine these matrices across 6- and 12-month estimates and LHS variables
		if "`lhs'" == "ln_emp" {
			mat effect`ind' = effect`ind'_6month, effect`ind'_12month
			mat mspe_ratio`ind' = mspe_ratio`ind'_6month, mspe_ratio`ind'_12month
			mat mspe_pval`ind' = mspe_pval`ind'_6month, mspe_pval`ind'_12month
			mat N`ind' = N`ind'_6month, N`ind'_12month
			mat mspe_stars`ind' = mspe_stars`ind'_6month, mspe_stars`ind'_12month
		}
		else if "`lhs'" != "ln_emp" {
			mat effect`ind' = effect`ind', effect`ind'_6month, effect`ind'_12month
			mat mspe_ratio`ind' = mspe_ratio`ind', mspe_ratio`ind'_6month, mspe_ratio`ind'_12month
			mat mspe_pval`ind' = mspe_pval`ind', mspe_pval`ind'_6month, mspe_pval`ind'_12month
			mat N`ind' = N`ind', N`ind'_6month, N`ind'_12month
			mat mspe_stars`ind' = mspe_stars`ind', mspe_stars`ind'_6month, mspe_stars`ind'_12month
		}	
			
		* Combine the matrices into one
		mat vals`ind' = effect`ind'
		mat mspevals`ind' = mspe_ratio`ind'\mspe_pval`ind'
		
		* Now make the tables *if* we've looped through to the last lhs variable (ln_estabs)
		if "`lhs'" == "ln_estabs" {
											
			* Make the combined tables
			frmttable using "$prdir/out/analysis/cz_`c'/tables/combined/qcew_naics_`ind'", replace tex statmat(vals`ind') sdec(4) ///
			annotate(mspe_stars`ind') asymbol(*,**,***) ///
			ctitles("`industry'","Log","","","Log compensation","","Log",""\"`industry2'","employment","""","per worker","","establishments",""\"","6 month TE","12 month TE","6 month TE","12 month TE","6 month TE","12 month TE") ///
			rtitles("Treatment effect")
						
			frmttable using "$prdir/out/analysis/cz_`c'/tables/combined/qcew_naics_`ind'", replace tex statmat(mspevals`ind') sdec(4) ///
			rtitles("RMSPE"\"RMSPE p-value") append
						
			frmttable using "$prdir/out/analysis/cz_`c'/tables/combined/qcew_naics_`ind'", replace tex statmat(N`ind') sdec(0) ///
			rtitles("N") append
		}
	}
}

*-------------------------------------------------------------------------------
* Chart employment in Jacksonville, Orlando, and all placebo CZs
*-------------------------------------------------------------------------------

* Run employment synthetic control for Orlando, selected NAICS supersectors
foreach ind of numlist 10 23 {
	local graphlist ""
	
	* Run for each variable				
	foreach lhs in resid_ln_emp resid_ln_avg_wkly_wage resid_ln_estabs {
		local pdflist
						
		* Load the data
		use "$prdir/dta/analysis/qcew/sc_merged/cz_7400/`lhs'/irma_`c'_n`ind'_merged.dta", clear
		reshape long tr_effect_, i(_time time) j(cz)
		sort cz _time
								
		* Create macros with the number of placebos for the plot legend
		levelsof(cz), local(CZ)
		distinct cz
		local Jacksonville = r(ndistinct) + 1
		local Orlando = r(ndistinct) + 2
				
		* Clean up and reshape back
		reshape wide tr_effect_, i(_time time) j(cz)
                               
		* Create locals for the placebo results and put treatment effects in percent terms
		local placebos
		foreach czone of local CZ {
			if "`czone'" != "7600" | "`czone'" != "7400" {
				if "`lhs'" == "resid_ln_emp" {
					local placebos "`placebos' line tr_effect_`czone' _time if inrange(tr_effect_`czone', -10, 10), lcolor(gs8) lp(solid) lwidth(vthin) || "
				}
				else if "`lhs'" != "resid_ln_emp" {
					local placebos "`placebos' line tr_effect_`czone' _time if inrange(tr_effect_`czone', -10, 10), lcolor(gs8) lp(solid) lwidth(vthin) || "
				}
				qui replace tr_effect_`czone' = 100*tr_effect_`czone'
			}
		}
			   
		* Define the locals to use for the graph titles
		if "`lhs'" == "resid_ln_emp" {
			local var = "`r_title'log employment"
			local var_label "employment"
		}
		else if "`lhs'" == "resid_ln_wagebill" {
			local var = "`r_title'log total compensation"
			local var_label "compensation (total)"
		}
		else if "`lhs'" == "resid_ln_avg_wkly_wage" {
			local var = "`r_title'log compensation per worker"
			local var_label "compensation per worker"
		}
		else if "`lhs'" == "resid_ln_estabs" {
			local var = "`r_title'log total establishments"
			local var_label "establishments"
		}
		if `ind' == 10 {
			if "`lhs'" == "resid_ln_emp" {
				local ind_label "Panel A: Aggregate Employment"
				local tlab "tlabel(`""')"
			}
			if "`lhs'" == "resid_ln_estabs" {
				local ind_label "Panel B: Aggregate Establishments"
				local tlab "tlabel(`""')"
			}
			local ticks ""
		}
		else if `ind' == 23 {
			if "`lhs'" == "resid_ln_emp" {
				local ind_label "Panel C: Construction Employment"
				local tlab "tlabel(2014m1(12)2018m1, angle(45))"
			}
			if "`lhs'" == "resid_ln_estabs" {
				local ind_label "Panel D: Construction Establishments"
				local tlab "tlabel(2014m1(12)2018m1, angle(45))"
			}
			local ticks "ttick(#5)"
		}
          
		* Create the graphs
		tsset _time, monthly
		if "`lhs'" == "resid_ln_emp" {
		  #delimit ;
				twoway  
					`placebos'||
					(line tr_effect_7600 _time if inrange(tr_effect_7600, -10, 10), lcolor(black) lp(shortdash)) ||
					(line tr_effect_7400 _time if inrange(tr_effect_7400, -10, 10), lcolor(black) lp(solid)),
					xline(691.5, lwidth(1) lcolor(gs12))
					xline(691 692, lp(dot) lcolor(gs8))
					title("`ind_label'") xtitle("") ytitle("")
					plotregion(margin(zero))
					yscale(range(-10 10)) ylabel(-10 (4) 10)
					`tlab' `ticks'
					graphregion(fcolor(white)) plotregion(fcolor(white) margin(0 0 0 0)) bgcolor(white)
					legend(order(`Orlando' "Orlando" `Jacksonville' " Jacksonville") region(lwidth(thin) lcolor(gs10)));
				#delimit cr
				
			* Copy it
			graph copy gr_emp`ind', replace
		}
		else if "`lhs'" != "resid_ln_emp" {
			#delimit ;
				twoway 
					`placebos'||
					(line tr_effect_7600 _time if inrange(tr_effect_7600, -10, 10), lcolor(black) lp(shortdash)) ||
					(line tr_effect_7400 _time if inrange(tr_effect_7400, -10, 10), lcolor(black) lp(solid)),
					xline(692.5, lwidth(4) lcolor(gs12))
					xline(691 694, lp(dot) lcolor(gs8))
					title("`ind_label'") xtitle("") ytitle("")
					plotregion(margin(zero))
					yscale(range(-10 10)) ylabel(-10 (4) 10)
					`tlab' ttick(#5)
					graphregion(fcolor(white)) plotregion(fcolor(white) margin(0 0 0 0)) bgcolor(white)
					legend(order(`Orlando' "Orlando" `Jacksonville' " Jacksonville") region(lwidth(thin) lcolor(gs10)));
				#delimit cr
				
			* Copy it
			graph copy gr_ests`ind', replace
			if `ind' == 23 & "`lhs'" == "resid_ln_estabs" {
				local graphlist "gr_emp10 gr_ests10 gr_emp23 gr_ests23"
			}
		}
				
		nicepdf "$prdir/out/analysis/cz_7600/nice_graphs/te_`lhs'_n`ind'.pdf", replace
	}
}

* Place all the employment plots on one graph, and all the earnings plots on one graph
di "graphlist: `graphlist'"
qui grc1leg `graphlist', imargin(vsmall) legendfrom(gr_ests23)
qui graph export "$prdir/out/analysis/cz_7600/nice_graphs/combined_emp_estabs.pdf", replace

* Close the log file
log close sublog
