capture log close sublog
log using "$prdir/log/analysis/qcew/oth_synth_placebo_qcew_cz.txt", name(sublog) text replace

*-------------------------------------------------------------------------------
* Description: Run placebo tests for synthetic control analysis of
* deseasonalized QCEW variables, by CZ, for the top 2-5 per-capita CZ recipients
* of PR migrants, and top 2-3
* Author: Justin Wiltshire
	
* Updated: May 6, 2021
*-------------------------------------------------------------------------------


* Loop over the other top 5 'treated' CZs
local czlist "7400 $other_treated_cz"
foreach c of local czlist {

	* Load the cleaned and deseasonalized QCEW data
	use "$prdir/dta/cln/qcew/deseasonalized_qcew_naics_cz.dta", clear
	  
	* Change settings for the synthetic control
	set matsize 11000
	  
	* Exclude all counties with >= 0.0001 FEMA applications per capita from donor pool
	foreach z of numlist $cz_droplist {
		if "`c'" != "`z'" {
			drop if cz == `z'
		}
	}
	
	* Ensure necessary folders exist
	qui capture mkdir "$prdir/dta/analysis/qcew/sc_placebo_tests/cz_`c'"
	qui capture mkdir "$prdir/dta/analysis/qcew/sc_placebo_tests/cz_`c'/yr_hole"
	  
	* Keep for 2014 and later (after the recovery had firmly taken root)
	keep if year >= 2014
	  
	tempfile core
	save "`core'"
	  
	* Run employment synthetic control for Orlando, selected NAICS supersectors
	foreach ind of numlist 10 23 44 72 {
		use "`core'", clear
			
		* Restrict the donor pool to CZs of appropriate size
		qui sum emp if naics == `ind', d
		keep if emp >= r(p75) & naics == `ind'
				
		* Keep the industry of interest  
		keep if naics == `ind'
			  
		* Keep only CZs which observe the industry in each period and skip the estimations if the CZ is dropped from the sample
		bysort cz: egen ct = count(ln_emp)
		qui sum ct, d
		qui gen rmax = r(max)
		qui sum ct if cz == `c', d
		if r(N) == rmax {
			keep if ct == rmax
				
			tempfile core2
			save "`core2'"
				  
			* Run through each of the donor pools CZs as a placebo test
			levelsof(cz), local(CZ)
			foreach czone of local CZ {
				if "`czone'" != "`c'" {
					use "`core2'", clear
					  
					* Set up and run the synthetic control estimations
					tsset cz tm
					  
					* Synthetic control for each of the LHS variables
					foreach lhs of varlist resid_ln_emp resid_ln_avg_wkly_wage resid_ln_wagebill resid_ln_estabs {
						if "`lhs'" == "resid_ln_emp" {
							local emp_qtr "`lhs'(691)"
							local trperiod = 692
							local last_pretreat = 691
						}
						else if "`lhs'" != "resid_ln_emp" {
							local emp_qtr ""
						
							* Non-employment variables are only observed quarterly
							keep if inlist(month(dofm(tm)), 2, 5, 8, 11)
							local trperiod = 691
							local last_pretreat = 688
						}
						
						* Ensure necessary folders exist
						qui capture mkdir "$prdir/dta/analysis/qcew/sc_placebo_tests/cz_`c'/`lhs'"
						qui capture mkdir "$prdir/dta/analysis/qcew/sc_placebo_tests/cz_`c'/`lhs'/top5"
					
						* Note the particular run
						di "Placebo CZ `czone' for treated CZ `c'; NAICS `ind'; LHS `lhs'"
						
						#delimit ;
							qui synth 
								`lhs' `emp_qtr' `lhs'(688) `lhs'(685) `lhs'(682) `lhs'(679) `lhs'(676) `lhs'(673) `lhs'(661) `lhs'(655) `lhs'(649)
								prop_emp_23(649(3)`last_pretreat') prop_emp_72(649(3)`last_pretreat'), trunit(`czone') trperiod(`trperiod') fig 
								keep("$prdir/dta/analysis/qcew/sc_placebo_tests/cz_`c'/`lhs'/top5/n`ind'_cz`czone'.dta") replace;
							#delimit cr  
					}
				}
			}  
		}		  
	}	
}

* Loop over the other top 3 'treated' CZs
local czlist "7400 $top3_treated_cz"
foreach c of local czlist {

	* Load the cleaned and deseasonalized QCEW data
	use "$prdir/dta/cln/qcew/deseasonalized_qcew_naics_cz.dta", clear
	  
	* Change settings for the synthetic control
	set matsize 11000
	  
	* Exclude all counties with >= 0.0001 FEMA applications per capita from donor pool
	foreach z of numlist $cz_droplist {
		if "`c'" != "`z'" {
			drop if cz == `z'
		}
	}
	
	* Ensure necessary folders exist
	qui capture mkdir "$prdir/dta/analysis/qcew/sc_placebo_tests/cz_`c'"
	qui capture mkdir "$prdir/dta/analysis/qcew/sc_placebo_tests/cz_`c'/yr_hole"
	  
	* Keep for 2014 and later (after the recovery had firmly taken root)
	keep if year >= 2014
	  
	tempfile core
	save "`core'"
	  
	* Run employment synthetic control for Orlando, selected NAICS supersectors
	foreach ind of numlist 10 23 44 72 {
		use "`core'", clear
			
		* Restrict the donor pool to CZs of appropriate size
		qui sum emp if naics == `ind', d
		keep if emp >= r(p75) & naics == `ind'
				
		* Keep the industry of interest  
		keep if naics == `ind'
			  
		* Keep only CZs which observe the industry in each period and skip the estimations if the CZ is dropped from the sample
		bysort cz: egen ct = count(ln_emp)
		qui sum ct, d
		qui gen rmax = r(max)
		qui sum ct if cz == `c', d
		if r(N) == rmax {
			keep if ct == rmax
				
			tempfile core2
			save "`core2'"
				  
			* Run through each of the donor pools CZs as a placebo test
			levelsof(cz), local(CZ)
			foreach czone of local CZ {
				if "`czone'" != "`c'" {
					use "`core2'", clear
					  
					* Set up and run the synthetic control estimations
					tsset cz tm
					  
					* Synthetic control for each of the LHS variables
					foreach lhs of varlist resid_ln_emp resid_ln_avg_wkly_wage resid_ln_wagebill resid_ln_estabs {
						if "`lhs'" == "resid_ln_emp" {
							local emp_qtr "`lhs'(691)"
							local trperiod = 692
							local last_pretreat = 691
						}
						else if "`lhs'" != "resid_ln_emp" {
							local emp_qtr ""
						
							* Non-employment variables are only observed quarterly
							keep if inlist(month(dofm(tm)), 2, 5, 8, 11)
							local trperiod = 691
							local last_pretreat = 688
						}
						
						* Ensure necessary folders exist
						qui capture mkdir "$prdir/dta/analysis/qcew/sc_placebo_tests/cz_`c'/`lhs'"
						qui capture mkdir "$prdir/dta/analysis/qcew/sc_placebo_tests/cz_`c'/`lhs'/top3"
					
						* Note the particular run
						di "Placebo CZ `czone' for treated CZ `c'; NAICS `ind'; LHS `lhs'"
						
						#delimit ;
							qui synth 
								`lhs' `emp_qtr' `lhs'(688) `lhs'(685) `lhs'(682) `lhs'(679) `lhs'(676) `lhs'(673) `lhs'(661) `lhs'(655) `lhs'(649)
								prop_emp_23(649(3)`last_pretreat') prop_emp_72(649(3)`last_pretreat'), trunit(`czone') trperiod(`trperiod') fig 
								keep("$prdir/dta/analysis/qcew/sc_placebo_tests/cz_`c'/`lhs'/top3/n`ind'_cz`czone'.dta") replace;
							#delimit cr  
					}
				}
			}  
		}		  
	}	
}

* Close the log file
log close sublog
