capture log close sublog
log using "$prdir/log/analysis/qwi/merge_te_6month.txt", name(sublog) text replace

*-------------------------------------------------------------------------------
* Description: Merge the treatment effect results from the synthetic control and
* the placebo synthetic control estimations
* Author: Justin Wiltshire
	
* Updated: September 14, 2021
*-------------------------------------------------------------------------------

tempfile core

* Set Orlando as the treated unit
local c = 7400  

* Loop over the different QWI data sets
foreach dem in nonhisp lessthanhs hsorless somecollplus {

	* Load the cleaned and deseasonalized QWI data sets
	qui use "$prdir/dta/cln/qwi/deseasonalized_qwi_naics_cz_`dem'.dta", clear

	* Change settings for the synthetic control
	qui set matsize 11000

	* Exclude all counties with >= 0.0001 FEMA applications per capita from donor pool
	foreach z of numlist $cz_droplist {
		if "`c'" != "`z'" {
			qui drop if cz == `z'
		}
	}

	* Keep for 2014 and later (after the recovery had firmly taken root)
	qui keep if year >= 2014
	qui save "`core'", replace

	* Run employment synthetic control for Orlando, selected NAICS supersectors
	qui local n = 0
	foreach ind of numlist 10 23 44 72 {
		qui use "`core'", clear
		  
		* Restrict the donor pool to CZs of appropriate size
		qui sum emp if naics == `ind', d
		qui keep if emp >= r(p75) & naics == `ind'
      
		* Keep only CZs which observe the industry in each period and skip the estimations if the CZ is dropped from the sample
		bysort cz: egen ct = count(ln_emp)
		qui sum ct, d
		qui gen rmax = r(max)
		qui sum ct if cz == 7400, d
		if r(N) == rmax {
			qui keep if ct == rmax              
			qui levelsof(cz), local(CZ)
		  
			* Create the datasets containing the results and the placebo test results
  			qui local resid "resid_"
  			qui local deseason "deseasonalize_"

			* Run for each variable				
			foreach lhs in `resid'ln_emp `resid'ln_avg_wkly_wage `resid'ln_wagebill {
			
				* Make necessary folders
				qui capture mkdir "$prdir/dta/analysis/qwi/`dem'/sc_merged"
				qui capture mkdir "$prdir/dta/analysis/qwi/`dem'/sc_merged/cz_7400"
				qui capture mkdir "$prdir/dta/analysis/qwi/`dem'/sc_merged/cz_7400"
				qui capture mkdir "$prdir/dta/analysis/qwi/`dem'/sc_merged/cz_7400/`lhs'"

					
				* Load the Orlando results and set up the dataset for creating the graphs
				qui use "$prdir/dta/analysis/qwi/`dem'/sc_results_dta/cz_7400/`lhs'/`deseason'n`ind'.dta", clear
				qui gen time = yq(year(dofm(_time)), ceil(month(dofm(_time))/3))
				qui format time %tq
				qui gen tr_effect_orl = _Y_treated - _Y_synthetic
				qui keep _time time tr_effect_orl
				qui keep if !mi(_time)
				qui save "$prdir/dta/analysis/qwi/`dem'/sc_merged/cz_7400/`lhs'/`deseason'n`ind'_merged.dta", replace
				  
				* Run through the results from each of the donor pool CZs as a placebo test, and merge with the above
				foreach czone of local CZ {
					if "`czone'" != "7400" {
						qui use "$prdir/dta/analysis/qwi/`dem'/sc_placebo_tests/cz_7400/`lhs'/n`ind'_cz`czone'.dta", clear
						qui gen time = yq(year(dofm(_time)), ceil(month(dofm(_time))/3))
						qui format time %tq
						qui gen tr_effect_`czone' = _Y_treated - _Y_synthetic
						qui keep _time time tr_effect_`czone'
						qui keep if !mi(_time)
						merge 1:1 _time using "$prdir/dta/analysis/qwi/`dem'/sc_merged/cz_7400/`lhs'/`deseason'n`ind'_merged.dta", nogenerate noreport
						qui format _time %tm
						qui save "$prdir/dta/analysis/qwi/`dem'/sc_merged/cz_7400/`lhs'/`deseason'n`ind'_merged.dta", replace
					}
				}
			}
		}
	}
}
	
* Close the log file
log close sublog
