capture log close sublog
log using "$prdir/log/analysis/qwi/andrews_and_cwz_p_values.txt", name(sublog) text replace

*-------------------------------------------------------------------------------
* Description: Calculate Andrews test p-values for each post-
* treatment event year, for each variable. Then calcuate Chernozhukov, Wuthrich, 
* and Zhu moving-block p-values for last event-year
*
* Updated: August 1, 2020
*-------------------------------------------------------------------------------

*-------------------------------------------------------------------------------
* Andrews test p-values
*-------------------------------------------------------------------------------

tempfile core
foreach dem in nonhisp hsorless {
	foreach ind in 10 23 44 72 {
		foreach lhs in resid_ln_emp resid_ln_avg_wkly_wage  {

			* Load the synthetic control weights
			qui use "$prdir/dta/analysis/qwi/`dem'/sc_results_dta/cz_7400/`lhs'/deseasonalize_n`ind'_1year.dta", clear
		
			* Generate event year and keep only obs of interest
			qui drop if mi(_Y_treated)
		
			* Generate the period-specific sum of squared prediction errors (treatment effects)
			qui gen s_hat = (_Y_treated - _Y_synthetic)^2
		
			* Keep key variables
			rename _time tm
			qui keep tm s_hat
			
			* Set trperiod local
			local tp = 691
			
			* Set up the data
			qui gen x = _n if tm >= `tp'
			qui egen xx = min(x)
			qui replace x = x - xx
			qui gen y = _n if tm < `tp'
			qui egen yy = max(y)
			qui replace y = y - yy - 1
			qui replace x = y if mi(x)
			qui rename x evt_year
			qui drop xx y yy
			qui sum evt_year
			local rmax = r(max)
			
			* Calculate the Andrews test p-values
			qui gen x = evt_year if evt_year >= 0
			qui tempfile core
			qui save "`core'", replace
			forval e = 0/`rmax' {
				qui use "`core'", clear
				qui keep if x == `e' | mi(x)
				qui drop x
				qui distinct evt_year if evt_year < 0
				local rN = r(N) + 1
				gsort -s_hat
				qui gen rank = _n
				list
				qui keep if evt_year >= 0
				qui gen p = rank/`rN'
				local rank = rank
				local p = p
				di "Outcome: `v'; event year: `e'; N: `rn'; rank: `rank'; Andrews p-value: `p'"
				
				* Comfirm directory exists, and save
				qui capture mkdir "$prdir/dta/analysis/qwi/`dem'/andrews_tests"
				qui compress
				qui save "$prdir/dta/analysis/qwi/`dem'/andrews_tests/`lhs'_ind`ind'_event_year_`e'1year.dta", replace
			}
		}
	}

	*-------------------------------------------------------------------------------
	* Chernozhukov, Wuthrich, and Zhu moving-block p-values
	*-------------------------------------------------------------------------------
	
	di "CWZ moving-block p-values; LHS: `lhs'"

	tempfile core
	foreach ind in 10 23 44 72 {
		foreach lhs in resid_ln_emp resid_ln_avg_wkly_wage {
				forval a = 0/1 {

				* Load the synthetic control weights
				qui use "$prdir/dta/analysis/qwi/`dem'/sc_results_dta/cz_7400/`lhs'/deseasonalize_n`ind'_1year.dta", clear
			
				if `a' == 1 {
					keep if _time <= 698
				}
				
				* Prepare the data
				qui drop if mi(_Y_treated)
				rename _time tm
				qui gen tr_effect = _Y_treated - _Y_synthetic
				qui keep tr_effect tm
				
				* Set trperiod local
				local tp = 691
				
				* Set up the data
				qui gen x = _n if tm >= `tp'
				qui egen xx = min(x)
				qui replace x = x - xx
				qui gen y = _n if tm < `tp'
				qui egen yy = max(y)
				qui replace y = y - yy - 1
				qui replace x = y if mi(x)
				qui rename x evt_year
				qui drop xx y yy
				qui sum evt_year
				local rmax = r(max)
				local rmin = r(min)
				local max1 = `rmax' + 1
				qui drop tm
				qui rename evt_year permuted_final_evt_year
			
				* Loop through the event periods
				tempfile core2
				forval e = `rmax'(-1)`rmin' {
					if `e' != `rmax' {
						qui use "`core2'", clear
						replace permuted_final_evt_year = permuted_final_evt_year + 1
						recode permuted_final_evt_year (`max1'=`rmin')
					}
					sort permuted_final_evt_year
					qui save "`core2'", replace
					
					* Generate the test statistic
					qui distinct permuted_final_evt_year if permuted_final_evt_year >= 0
					local rN = r(N)
					qui egen x = total(abs(tr_effect)) if inrange(permuted_final_evt_year, 0, `rmax')
					qui gen s = x/`rN'
					qui drop x
					
					* Keep only (permuted) event year rmax and recode with actual event year
					qui keep if permuted_final_evt_year == `rmax'
					qui gen evt_year = `e'
					
					* Comfirm directory exists, and save
					qui capture mkdir "$prdir/dta/analysis/qwi/`dem'/moving_block_pval"
					qui compress
					if `e' != `rmax' {
						qui append using "$prdir/dta/analysis/qwi/`dem'/moving_block_pval/`lhs'_ind`ind'_event_year_`rmax'1year.dta"
					}
					qui save "$prdir/dta/analysis/qwi/`dem'/moving_block_pval/`lhs'_ind`ind'_event_year_`rmax'1year.dta", replace

					* Drop x & s for next loop
					qui drop s evt_year
				}
				
				* Calculate p-values
				qui use "$prdir/dta/analysis/qwi/`dem'/moving_block_pval/`lhs'_ind`ind'_event_year_`rmax'1year.dta", clear
				qui drop permuted_final_evt_year
				order evt_year tr_effect s
				qui distinct evt_year if evt_year != `rmax'
				local eN = r(N)
				qui sort s
				qui gen rank = _n - 1
				qui gen f = rank/`eN'
				qui gen p = 1 - f
				
				* Keep event year rmax and save
				qui keep if evt_year == `rmax'
				qui compress
				qui save "$prdir/dta/analysis/qwi/`dem'/moving_block_pval/`lhs'_ind`ind'_event_year_`rmax'1year.dta", replace
			}
		}
	}
}
* Close the log
log close sublog
