capture log close sublog
log using "$prdir/log/build/deseasonalize_qcew_naics_cz.txt", name(sublog) text replace

*-------------------------------------------------------------------------------
* Description: Deseasonalize the QCEW data by commuting zone for each industry
* Author: Justin Wiltshire
	
* Updated: September 27, 2021
*-------------------------------------------------------------------------------

* Load the QCEW by CZ data
use "$prdir/dta/cln/qcew/qcew_naics_cz.dta", clear

* Create month variable
gen month = month(dofm(tm))

* Create employment-industry proportions to be controls
bysort cz tm (naics): gen prop_emp_23 = prop_emp[5]
bysort cz tm (naics): gen prop_emp_44 = prop_emp[8]
bysort cz tm (naics): gen prop_emp_48 = prop_emp[9]
bysort cz tm (naics): gen prop_emp_72 = prop_emp[19]

keep if inlist(naics, 10, 23, 44, 48, 72)

tempfile core
save "`core'"

* Deseasonalize key variables by CZ
levelsof(naics), local(naics)
foreach ind of local naics {
  
  ** Log employment **
  * Re-load the main file and restrict to ind
  qui use "`core'", clear
  keep if naics == `ind'
  
  * Keep only CZs with employment observations at least once in each quarter
  bysort cz quarter: egen obs_cz_qtr = count(ln_emp)
  qui gen flag_zeros = 1 if obs_cz_qtr == 0
  bysort cz: egen flag_drop = count(flag_zeros)
  drop if flag_drop > 0
  drop obs_cz_qtr flag*
  
  * Initialize residual employment then populate it
  qui gen resid_ln_emp = .
  quietly levelsof cz, local(cz)
  foreach z of local cz {
    di "NAICS `ind'; ln_emp; Commuting Zone `z'"
    qui reg ln_emp i.month if cz == `z'
    qui predict double resid_ln_emp_`z' if cz == `z', residuals
    qui replace resid_ln_emp = resid_ln_emp_`z' if cz == `z'
    drop resid_ln_emp_`z'
  }
  * Compress and save
  compress
  save "$prdir/dta/cln/qcew/qcew_naics`ind'_cz.dta", replace
  
  ** Log wagebill, log establishments, and log average weekly wage
  * Re-load the main file and restrict to ind
  foreach v of varlist ln_avg_wkly_wage ln_wagebill ln_estabs { 
    qui use "`core'", clear
    keep if naics == `ind'
    keep if inlist(month, 2, 5, 8, 11)
    
    * Keep only CZs with variables observations at least once in each quarter
    bysort cz quarter: egen obs_cz_qtr = count(`v')
    qui gen flag_zeros = 1 if obs_cz_qtr == 0
    bysort cz: egen flag_drop = count(flag_zeros)
    drop if flag_drop > 0
    drop obs_cz_qtr flag*
    
    * Initialize residual variable then populate it
    qui gen resid_`v' = .
    quietly levelsof cz, local(cz)
    foreach z of local cz {
      di "NAICS `ind'; `v'; Commuting Zone `z'"
      qui reg `v' i.month if cz == `z'
      qui predict double resid_`v'_`z' if cz == `z', residuals
      qui replace resid_`v' = resid_`v'_`z' if cz == `z'
      drop resid_`v'_`z'
    }
    * Compress, merge and save
    compress
    merge 1:1 cz tm using "$prdir/dta/cln/qcew/qcew_naics`ind'_cz.dta", nogenerate
    save "$prdir/dta/cln/qcew/qcew_naics`ind'_cz.dta", replace
  }
}

* Append the datasets together
foreach ind of local naics {
	if "`ind'" == "10" {
		use "$prdir/dta/cln/qcew/qcew_naics`ind'_cz.dta", clear
	}
	else if "`ind'" != "10" {
		append using "$prdir/dta/cln/qcew/qcew_naics`ind'_cz.dta"
	}
	erase "$prdir/dta/cln/qcew/qcew_naics`ind'_cz.dta"
}

* Save
save "$prdir/dta/cln/qcew/deseasonalized_qcew_naics_cz.dta", replace

* Close the log file
log close sublog
