capture log close sublog
log using "$prdir/log/build/qwi/qwi_builder.txt", name(sublog) text replace

*-------------------------------------------------------------------------------
* Description: Process the QWI data for hispanics, non-hispanics, less than HS,
* HS or less, and some college or more: 2014Q1-2018Q3
* Author: Justin Wiltshire
*
* Updated: July 31, 2020
*-------------------------------------------------------------------------------

* Do for each sub-sample
* Loop over ethnicity & education
foreach z in ethnicity education some_college {
	
	* Load the data
	if "`z'" != "all_ethnic" {
		qui use "$prdir/dta/src/qwi/qwi_`z'.dta", clear
	}
	if "`z'" == "all_ethnic" {
		qui use "$prdir/dta/src/qwi/qwi_ethnicity.dta", clear
	}
			
	* Keep, rename, and generate variables of interest
	if "`z'" == "ethnicity" {
		qui keep geography industry ethnicity race year quarter emp payroll
		qui keep if race == "A0"
		bysort geography industry year quarter (ethnicity): replace emp = emp - emp[2] if _n == 1
		qui gen nonhisp = (ethnicity == "A1")
		qui drop ethnicity race
		label var nonhisp "Non-Hispanic & non-Latino"
	}
	if "`z'" == "education" {
		qui keep geography industry education year quarter emp payroll
		qui drop if !inlist(education, "E1", "E2")
		qui gen lessthanhs = (education == "E1")
		qui drop education
		label var lessthanhs "Less than high school or equiv"
	}
	if "`z'" == "some_college" {
		qui keep geography industry education year quarter emp payroll
		qui drop if !inlist(education, "E3", "E4")
		qui gen somecollplus = !mi(education)
		qui drop education
		label var somecollplus "Some college or higher attainment"
	}
	qui rename industry naics
	qui replace naics = "10" if naics == "00"
	qui replace naics = "31" if naics =="31-33"
	qui replace naics = "44" if naics == "44-45"
	qui destring naics, replace
	qui rename payroll wagebill
	qui drop if geography < 57
	qui rename geography cty_fips
	qui gen month = 2*(quarter == 1) + 5*(quarter == 2) + 8*(quarter == 3) + 11*(quarter == 4)
	qui gen int tm = ym(year, month)
	qui format %tm tm
			
	* Label variables
	label var cty_fips "County FIPS code"
	label var naics "NAICS/supersector code"
	label var tm "Year/month"
	label var emp "Employment (reported total)"
	label var wagebill "Real wage bill (reported total)"
			
	* Map into consistent county codes
	qui cty_remap
			
	* Aggregate up
	if "`z'" == "ethnicity" {
		qui collapse (sum) emp wagebill, by(cty_fips naics nonhisp tm)
	}
	if "`z'" == "education" {
		qui collapse (sum) emp wagebill, by(cty_fips naics lessthanhs tm)
	}
	if "`z'" == "some_college" {
		qui keep if tm <= 703
		qui collapse (sum) emp wagebill, by(cty_fips naics somecollplus tm)
	}
			
	* Deflate wage bill
	qui merge m:1 tm using "$prdir/cw/pce/dta/cln/pce_mth.dta", keep(3) keepusing(pce) nogenerate
	qui replace wagebill = wagebill/pce
	qui drop pce
		
	* Drop Alaska and Hawaii
	drop if inlist(floor(cty_fips/1000), 2, 15)
			
	* Split and save by sample of interest
	qui compress
	qui sort cty_fips naics tm
	qui order cty_fips naics tm emp wagebill
	if "`z'" == "ethnicity" {
		qui preserve
		qui keep if nonhisp == 1
		qui drop nonhisp
		save "$prdir/dta/cln/qwi/qwi_naics_cty_nonhisp.dta", replace
		qui restore, preserve
		qui keep if nonhisp == 0
		qui drop nonhisp
		qui save "$prdir/dta/cln/qwi/qwi_naics_cty_hisp.dta", replace
		qui restore
		qui collapse (sum) emp wagebill, by(cty_fips naics tm)
		qui save "$prdir/dta/cln/qwi/qwi_naics_cty_all_ethnic.dta", replace
	}
	if "`z'" == "all_ethnic" {
		qui keep if all_ethnic == 1
		qui drop all_ethnic
		save "$prdir/dta/cln/qwi/qwi_naics_cty_all_ethnic.dta", replace
	}
	if "`z'" == "education" {
		qui preserve
		qui keep if lessthanhs == 1
		qui drop lessthanhs
		qui save "$prdir/dta/cln/qwi/qwi_naics_cty_lessthanhs.dta", replace
		qui restore
		qui collapse (sum) emp wagebill, by(cty_fips naics tm)
		qui save "$prdir/dta/cln/qwi/qwi_naics_cty_hsorless.dta", replace
	}
	if "`z'" == "some_college" {
		qui keep if somecollplus == 1
		qui save "$prdir/dta/cln/qwi/qwi_naics_cty_somecollplus.dta", replace
	}
}

* And non-Hispanic whites, specifically

* Load the data
qui use "$prdir/dta/src/qwi/qwi_ethnicity.dta", clear
			
* Keep, rename, and generate variables of interest
qui keep geography industry ethnicity race year quarter emp payroll
qui keep if race == "A1"
bysort geography industry year quarter (ethnicity): replace emp = emp - emp[2] if _n == 1
qui gen nonhisp = (ethnicity == "A1")
qui drop ethnicity race
label var nonhisp "Non-Hispanic & non-Latino Whites"

qui rename industry naics
qui replace naics = "10" if naics == "00"
qui replace naics = "31" if naics =="31-33"
qui replace naics = "44" if naics == "44-45"
qui destring naics, replace
qui rename payroll wagebill
qui drop if geography < 57
qui rename geography cty_fips
qui gen month = 2*(quarter == 1) + 5*(quarter == 2) + 8*(quarter == 3) + 11*(quarter == 4)
qui gen int tm = ym(year, month)
qui format %tm tm
			
* Label variables
label var cty_fips "County FIPS code"
label var naics "NAICS/supersector code"
label var tm "Year/month"
label var emp "Employment (reported total)"
label var wagebill "Real wage bill (reported total)"
			
* Map into consistent county codes
qui cty_remap
			
* Aggregate up
qui collapse (sum) emp wagebill, by(cty_fips naics nonhisp tm)

* Deflate wage bill
qui merge m:1 tm using "$prdir/cw/pce/dta/cln/pce_mth.dta", keep(3) keepusing(pce) nogenerate
qui replace wagebill = wagebill/pce
qui drop pce
		
* Drop Alaska and Hawaii
drop if inlist(floor(cty_fips/1000), 2, 15)
			
* Split and save by sample of interest
qui compress
qui sort cty_fips naics tm
qui order cty_fips naics tm emp wagebill
qui keep if nonhisp == 1
qui drop nonhisp
save "$prdir/dta/cln/qwi/qwi_naics_cty_nonhisp_white.dta", replace

* Close the log
log close sublog

