capture log close sublog
log using "$prdir/log/check/hisp_orl_emp_shr_by_ind_q2.txt", name(sublog) text replace

*-------------------------------------------------------------------------------
* Description: Plot Orlando's Hispanic employment share by industry
* Author: Justin Wiltshire
	
* Updated: February 13, 2020
*-------------------------------------------------------------------------------

* Hispanic QWI data
* Loop over Q2 2016 - 2018
forval t = 676(12)700 {

	* Load the Hispanic QWI data
	qui use "$prdir/dta/cln/qwi/qwi_naics_cz_hisp.dta", clear

	* Restrict the data to the separate industries in Q2 in each year in Orlando
	qui keep if tm == `t' & cz == 7400
	qui keep cz emp naics

	* Create the employment proportion by industry over this period
	qui rename emp hisp_emp
	
	* Define and apply the industry label
	label define indlab 10 "Aggregate" 23 "NAICS 23 Construction" 31 "NAICS 31-33 Manufacturing" 42 "NAICS 42 Wholesale trade" 44 "NAICS 44-45 Retail Trade" 62 "NAICS 62 Health care and social assistance" 71 "NAICS 71 Arts, entertainment, and recreation" 72 "NAICS 72 Accommodation and food services"
	label values naics indlab

	* Save tempfile
	if `t' == 676 {
		tempfile core
		qui save "`core'", replace
	}
	if `t' == 688 {
		tempfile core1
		qui save "`core1'", replace
	}
	if `t' == 700 {
		tempfile core2
		qui save "`core2'", replace
	}
}

* All worker QWI data
* Loop over Q2 2016 - 2018
forval t = 676(12)700 {

	* Load the Hispanic QWI data
	qui use "$prdir/dta/cln/qwi/qwi_naics_cz_all_ethnic.dta", clear

	* Restrict the data to the separate industries in Q2 in each year in Orlando
	qui keep if tm == `t' & cz == 7400
	qui keep cz emp naics
	
	* Define and apply the industry label
	label define indlab 10 "Aggregate" 23 "NAICS 23 Construction" 31 "NAICS 31-33 Manufacturing" 42 "NAICS 42 Wholesale trade" 44 "NAICS 44-45 Retail Trade" 62 "NAICS 62 Health care and social assistance" 71 "NAICS 71 Arts, entertainment, and recreation" 72 "NAICS 72 Accommodation and food services"
	label values naics indlab

	* Save tempfile
	if `t' == 676 {
		tempfile coreall
		qui save "`coreall'", replace
	}
	if `t' == 688 {
		tempfile coreall1
		qui save "`coreall1'", replace
		
		* Create industrial employment shares & remove total employment
		qui gen tot_emp = emp if naics == 10
		qui replace tot_emp = tot_emp[1]
		qui gen prop_emp = emp/tot_emp
		qui drop if naics == 10
		
		* Graph it
		#delimit ;
			qui graph 
				hbar prop_emp, 
				over(naics)
				bar(1, color(gs0))
				title("Industrial employment shares (QWI)")
				subtitle("All workers in Orlando, Q2 2017""(Selected industries)")
				ytitle("")
				b1title("Employment share")
				legend(label(1 "All workers (QWI)"))
				graphregion(color(white));
			#delimit cr
		qui graph export "$prdir/out/check/emp_shr/qwi_orl_emp_by_ind_all_2017q2.pdf", replace
	}
	if `t' == 700 {
		tempfile coreall2
		qui save "`coreall2'", replace
	}
}

* Load the Q2 2016 all worker data
qui use "`coreall'", clear

* Merge in the Hispanic data
qui merge 1:1 naics using "`core'"

* Create the Hispanic shares of employment by industry
qui gen hisp_prop_emp16 = hisp_emp/emp

* Save
tempfile both1
qui save "`both1'", replace

* Load the Q2 2017 all worker data
qui use "`coreall1'", clear

* Merge in the Hispanic data
qui merge 1:1 naics using "`core1'"

* Create the Hispanic shares of employment by industry
qui gen hisp_prop_emp17 = hisp_emp/emp

* Save
tempfile both2
qui save "`both2'", replace

* Load the Q2 2018 all worker data
qui use "`coreall2'", clear

* Merge in the Hispanic data
qui merge 1:1 naics using "`core2'"

* Create the Hispanic shares of employment by industry
qui gen hisp_prop_emp18 = hisp_emp/emp

* Merge in the 2016 & 2017 shares
qui merge 1:1 naics using "`both1'", norep nogen keepusing(hisp_prop_emp16)
qui merge 1:1 naics using "`both2'", norep nogen keepusing(hisp_prop_emp17)

* Graph it
#delimit ;
	qui graph 
		hbar hisp_prop_emp17 hisp_prop_emp18, 
		over(naics)
		bar(1, color(gs0)) bar(2, color(gs10))
		title("Hispanic share of industry employment")
		subtitle("Orlando (Selected industries)")
		ytitle("")
		b1title("Employment share")
		legend(rows(3) label(1 "Q2 2017 Hispanic share") label(2 "Q2 2018 Hispanic share"))
		graphregion(color(white));
	#delimit cr
qui graph export "$prdir/out/check/emp_shr/hisp_shr_orl_emp_by_ind_1718_q2.pdf", replace

* Graph the percentage point growth in share
qui gen hisp_prop_growth_1718 = 100*(hisp_prop_emp18 - hisp_prop_emp17)

#delimit ;
	qui graph 
		hbar hisp_prop_growth_1718, 
		over(naics)
		bar(1, color(gs0))
		ytitle("")
		b1title("Growth in Hispanic employment-share""(percentage points)")
		legend(rows(1) label(1 "Q2 2017- Q2 2018 growth in Hispanic share of employment, percentage points"))
		graphregion(color(white));
	#delimit cr
qui graph export "$prdir/out/check/emp_shr/hisp_shr_orl_empgrowth_by_ind_1718_q2.pdf", replace

* Close the log file
log close sublog
